@@ -1,7 +1,6 @@
-/* mpn/generic/divrem_1.c forced to use mul-by-inverse udiv_qrnnd_preinv. */
+/* mpn/generic/divrem_1.c forced to use mul-by-inverse udiv_qrnnd_preinv.
 
-/*
-Copyright 2000 Free Software Foundation, Inc.
+Copyright 2000, 2003 Free Software Foundation, Inc.
 
 This file is part of the GNU MP Library.
 
@@ -17,9 +16,10 @@ License for more details.
 
 You should have received a copy of the GNU Lesser General Public License
 along with the GNU MP Library; see the file COPYING.LIB.  If not, write to
-the Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-MA 02111-1307, USA.
-*/
+the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+MA 02110-1301, USA. */
+
+#define OPERATION_divrem_1
 
 #include "gmp.h"
 #include "gmp-impl.h"
